@@ -530,19 +530,27 @@ test_that("cmc__get_repos", {
 
   ## BioC, all new
   res <- cmc__get_repos(repos, TRUE, "good", r_version = "3.5")
-  expect_equal(res$name, c("CRAN", "BioCsoft", "BioCann", "BioCexp"))
+  expect_equal(
+    res$name,
+    c("CRAN", "BioCsoft", "BioCann", "BioCexp", "BioCworkflows"))
   expect_equal(res$url[1], "good")
-  expect_equal(res$type, c("cran", "bioc", "bioc", "bioc"))
-  expect_equal(res$bioc_version, c(NA_character_, "3.7", "3.7", "3.7"))
+  expect_equal(res$type, c("cran", "bioc", "bioc", "bioc", "bioc"))
+  expect_equal(
+    res$bioc_version,
+    c(NA_character_, "3.8", "3.8", "3.8", "3.8"))
 
   ## BioC, some are custom
   repos <- c(CRAN = "bad", BioCsoft = "ok")
   res <- cmc__get_repos(repos, TRUE, "good", r_version = "3.5")
-  expect_equal(res$name, c("CRAN", "BioCsoft", "BioCann", "BioCexp"))
+  expect_equal(
+    res$name,
+    c("CRAN", "BioCsoft", "BioCann", "BioCexp", "BioCworkflows"))
   expect_equal(res$url[1], "good")
   expect_equal(res$url[2], "ok")
-  expect_equal(res$type, c("cran", "bioc", "bioc", "bioc"))
-  expect_equal(res$bioc_version, c(NA_character_, "3.7", "3.7", "3.7"))
+  expect_equal(res$type, c("cran", "bioc", "bioc", "bioc", "bioc"))
+  expect_equal(
+    res$bioc_version,
+    c(NA_character_, "3.8", "3.8", "3.8", "3.8"))
 })
 
 test_that("download failures", {
